# Python Library for Control System

The OpenControl is a python package that implement basic algorithms for analysis and design of optimal feedback controllers.

## Features:

- Classical control methods
- Linear quadratic regulator (``LQR``) computation
- Robust Adaptive Dynamic Programming (``ADP``) for optimal linear/nonlinear control systems
- Off-policy, On-policy learning algorithms for linear/nonlinear systems
- Experience replay algorithms for linear/nonlinear systems (TODO)

## Development

You can check out the latest version of the source code with the command

   `git clone https://github.com/VNOpenAI/OpenControl`

You can run the unit tests with python to make sure that everything is
working correctly.  Inside the source directory, run

   `python test.py`

## Quick-start

For quick tutorials and application, please review the [Colab Notebook](https://colab.research.google.com/drive/10mYMDliuOZD5i-YqmD9noOL8JDhC6t3x?usp=sharing)

## Documentation 

Please check the lastest version of [document](https://opencontrol.readthedocs.io/en/latest/intro.html)